package com.ebelter.bpm_sdksdemo;

import android.bluetooth.BluetoothDevice;
import android.content.Intent;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;

import com.ebelter.sdks.bean.bpm.BpmHistoryResult;
import com.ebelter.sdks.bean.bpm.BpmMesureResult;
import com.ebelter.sdks.enums.ProductStyle;
import com.ebelter.sdks.interfaces.IBlueStationListener;
import com.ebelter.sdks.interfaces.IConnectStationCallback;
import com.ebelter.sdks.interfaces.bpm.BPMMeasureCallback;
import com.ebelter.sdks.managers.BpmManager;
import com.ebelter.sdks.models.products.bpm.BPMConstant;
import com.ebelter.sdks.utils.TimeUtils;


public class BpmActivity extends SDKBaseActivity {


    //public static final String TAG = "BpmActivity";

    private TextView tv0;
    private TextView tv1;
    private TextView tv2;
    private TextView mustconnect_tv;
    private TextView tv3;
    private TextView tv4;
    private Button start;

    private Button stop;

    private BpmManager mBpmManager;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_bpm);

        mBpmManager = new BpmManager(this);
        mBpmManager.setMustConnectBlueAddress(null);
        FV();
        setListeners();
        initData();
    }

    private void initData() {
        String sdkInfo = "versionName=" + AppUtils.getVerName(this) + "-versionCode=" + AppUtils.getVersionCode(this);
        setText(tv0, "EbelterSDK info:" + sdkInfo);

        setText(tv1, "蓝牙功能:" + (mBpmManager.isSupportBluetooth() ? "支持" : "不支持"));

        setText(tv2, "蓝牙状态:" + (mBpmManager.isBluetoothOpen() ? "已开启" : "已关闭"));


    }

    private void setListeners() {
        start.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                startWork();
            }
        });
        stop.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                stopWork();
            }
        });

        //设置手机蓝牙开关状态监听器
        mBpmManager.addBluetoothStationListener(mIBlueStationListener);
        //设置设备蓝牙连接断开的监器
        mBpmManager.setmIConnectStationCallback(mIConnectStationCallback);
        //设置设备测量的监听器
        mBpmManager.setMesuresCalBack(mBPMMeasureCallback);

    }




    private void addTv4Str(String addmsg) {

        String str;
        if (tv4 != null) {
            str = tv4.getText().toString();
            str = addmsg + "\n" + str;
            tv4.setText(str);
        }
    }


    private void setText(TextView tv, String msg) {
        if (tv != null) tv.setText(msg);
    }


    private void FV() {
        tv0 = findViewById(R.id.tv0);
        tv1 = findViewById(R.id.tv1);
        tv2 = findViewById(R.id.tv2);
        tv3 = findViewById(R.id.tv3);
        tv4 = findViewById(R.id.tv4);
        start = findViewById(R.id.start);

        stop = findViewById(R.id.stop);
        mustconnect_tv = findViewById(R.id.mustconnect_tv);
        mustconnect_tv.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                selectMustConnectAddress();
            }
        });
    }

    private void selectMustConnectAddress() {
        if (mBpmManager != null && mBpmManager.isWorkFlag()) {
            mBpmManager.stopWork();//先停止工作的意思
        }
        startActivityForResult(new Intent(this, SelectBlueActivity.class), 100);
    }

    //停止扫描连接
    private void stopWork() {
        mBpmManager.stopWork();
    }

    //开始扫描连接
    private void startWork() {
        mBpmManager.startWork();
    }

    private final IBlueStationListener mIBlueStationListener = new IBlueStationListener() {
        @Override
        public void STATE_OFF() {
            setText(tv2, "手机蓝牙状态:已关闭");
        }

        @Override
        public void STATE_TURNING_OFF() {
            setText(tv2, "手机蓝牙状态:正在关闭...");
        }

        @Override
        public void STATE_ON() {
            setText(tv2, "手机蓝牙状态:已开启");
        }

        @Override
        public void STATE_TURNING_ON() {
            setText(tv2, "手机蓝牙状态:正在打开...");
        }
    };

    private final IConnectStationCallback mIConnectStationCallback = new IConnectStationCallback() {
        @Override
        public void onConnected(ProductStyle productStyle, BluetoothDevice device) {
            setText(tv3, "血压计:已连接（" + device.getAddress() + ")");
        }

        @Override
        public void onConnecting(ProductStyle productStyle, BluetoothDevice device) {
            setText(tv3, "血压计:正在连接（" + device.getAddress() + ")...");
        }

        @Override
        public void onDisConnected(ProductStyle productStyle) {
            setText(tv3, "血压计:未连接");
        }
    };

    private final BPMMeasureCallback mBPMMeasureCallback = new BPMMeasureCallback() {
        @Override
        public void dynamicSystolicPressure(int value) {
            addTv4Str(TimeUtils.getCurrentTime1() + ":收到动态压力值 value = " + value);
        }

        @Override
        public void measureError(String connectName, int errorType) {
            addTv4Str(TimeUtils.getCurrentTime1() + ":收到测量错误信息 errorType = " + errorType);
            if (TextUtils.equals(connectName, BPMConstant.BPM_NAME2)) {
                String result = "";
                if (errorType == 1) {
                    result = "检测不到足够的心跳或算不出血压，请重新测量！";
                } else if (errorType == 2) {
                    result = "传感器震荡异常！";
                } else if (errorType == 3) {
                    result = "袖带过松或漏气(10秒内加压不到30mmHg)，请检查臂带并重新邦好。";
                } else if (errorType == 5) {
                    result = "测量结果异常！";
                } else if (errorType == 7) {
                    result = "测量出现错误，请重试！";
                } else if (errorType == 0x0b) {
                    result = "电池电量过低，请及时更换电池！";
                } else {
                    result = "测量出现错误，请重试！";
                }
                addTv4Str(result);
            } else {
                String result = "";
                if (errorType == 1) {
                    result = "检测不到结果";
                } else if (errorType == 2) {
                    result = "干扰太大";
                } else if (errorType == 3) {
                    result = "充气异常，打不上气或者压力超过上限";
                } else if (errorType == 5) {
                    result = "测量结果异常";
                } else if (errorType == 7) {
                    result = "其他错误";
                } else if (errorType == 0x0b) {
                    result = "电池电量过低，提示用户更换电池";
                } else {
                    result = "测量出现错误，请重试！";
                }
                addTv4Str(result);
            }
        }

        @Override
        public void measureResult(BpmMesureResult mesureResult) {

            //注意：测量出来的收缩压和舒张压永远是mmHg的值
            addTv4Str(TimeUtils.getCurrentTime1() + ":收到测量结果 " + mesureResult.toString());
        }

        @Override
        public void historyInProgress() {
            addTv4Str("正在接收历史记录");
        }

        @Override
        public void historyResult(BpmHistoryResult bpmHistoryResult) {
            addTv4Str(TimeUtils.getCurrentTime1() + ":收到历史结果 " + bpmHistoryResult.toString());
        }

        @Override
        public void historyDome() {
            addTv4Str( "历史记录上传完毕");
        }

        @Override
        public void noHistory() {
            addTv4Str("没有历史数据");
        }

        @Override
        public void reviceStartMeasure() {
            addTv4Str("血压计收到开始测量");
        }

        @Override
        public void reviceStopMeasure() {
            addTv4Str("血压计收到停止测量");
        }

        @Override
        public void reviceOffDisplay() {
            addTv4Str("血压计收到关屏");
        }

        @Override
        public void reviceShutdown() {
            addTv4Str("血压计收到关机");
        }

        @Override
        public void devicePower(int devicePower) {
            addTv4Str("设备电量值 = " + devicePower);
        }

        @Override
        public void unitKpa() {
            addTv4Str("单位 Kpa");
        }

        @Override
        public void unitMmhg() {
            addTv4Str("单位 mmHg");
        }

        @Override
        public void onlyScreen() {
            addTv4Str("13B4-LT专用息屏成功");
        }

        @Override
        public void onlyRecovery() {
            addTv4Str("13B4-LT专用恢复成功");
        }

        @Override
        public void pleaseSendUpdateTime() {
            addTv4Str("血压计请求更新时间");
        }

        @Override
        public void isUpdateDeviceTime(boolean isSuccess) {
            addTv4Str("血压计更新时间是否成功 = " + isSuccess);
        }

        @Override
        public void zhiLin(String msg) {
//            addTv4Str("血压计回复的原始指令 = "+msg);
        }
    };


    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (mBpmManager != null) {//界面退出的时候清理一下 内存回收比较快
            mBpmManager.removeBluetoothStationListener(mIBlueStationListener);
            mBpmManager.exit();
            mBpmManager = null;
        }
    }

    //把单位切换成mmHg 注意:正在测量的时候无法切换单位 只有在测量完成时或者测量错误之后才可以切换单位
    public void setUnitMMHG(View view) {
        if (!mBpmManager.isConnected()) {
            ToastUitl.show("请先连接设备");
            return;
        }
        mBpmManager.sendSwitUnitCmd(0);//把单位切换成mmHg
    }

    //把单位切换成KPA 注意:正在测量的时候无法切换单位 只有在测量完成时或者测量错误之后才可以切换单位
    public void setUnitKPA(View view) {
        if (!mBpmManager.isConnected()) {
            ToastUitl.show("请先连接设备");
            return;
        }
        mBpmManager.sendSwitUnitCmd(1);//把单位切换成KPA
    }

    // 获取历史记录
    public void getHistoryData(View view) {
        if (!mBpmManager.isConnected()) {
            ToastUitl.show("请先连接设备");
            return;
        }
        mBpmManager.get_history();//获取历史记录
    }

    // SN号
    public void getSnData(View view) {
        if (!mBpmManager.isConnected()) {
            ToastUitl.show("请先连接设备");
            return;
        }
        String deviceSn = mBpmManager.getDeviceSn();//关屏
        addTv4Str(TimeUtils.getCurrentTime1() + ":设备SN号 " + deviceSn);
    }

    // 关屏
    public void offDisplay(View view) {
        if (!mBpmManager.isConnected()) {
            ToastUitl.show("请先连接设备");
            return;
        }
        //关屏
        mBpmManager.offDisplay();
    }

    // 关机
    public void shutdown(View view) {
        if (!mBpmManager.isConnected()) {
            ToastUitl.show("请先连接设备");
            return;
        }
        //关机
        mBpmManager.shutdown();
    }

    // 13B4-LT专用熄屏
    public void onlyScreen(View view) {
        if (!mBpmManager.isConnected()) {
            ToastUitl.show("请先连接设备");
            return;
        }
        //13B4-LT专用熄屏
        mBpmManager.onlyScreen();
    }

    // 13B4-LT专用恢复
    public void onlyRecovery(View view) {
        if (!mBpmManager.isConnected()) {
            ToastUitl.show("请先连接设备");
            return;
        }
        //13B4-LT专用恢复
        mBpmManager.onlyRecovery();
    }


    // 获取电量
    public void sendToGetDevicePower(View view) {
        if (!mBpmManager.isConnected()) {
            ToastUitl.show("请先连接设备");
            return;
        }
        //获取电量
        mBpmManager.sendToGetDevicePower();
    }

    // 开始测量
    public void sendToStartMeasure(View view) {
        if (!mBpmManager.isConnected()) {
            ToastUitl.show("请先连接设备");
            return;
        }
        mBpmManager.sendToStartMeasure();
    }

    // 停止测量
    public void sendToStopMeasure(View view) {
        if (!mBpmManager.isConnected()) {
            ToastUitl.show("请先连接设备");
            return;
        }
        mBpmManager.sendToStopMeasure();
    }


    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (requestCode == 100 && resultCode == 101) {
            String mustConnectAddress = data.getStringExtra(SelectBlueActivity.ADDRESS);
            if (mustconnect_tv != null) {
                mustconnect_tv.setText(mustConnectAddress);
            }
        }
    }
}
